==> viriback2misp-0.7.tar.gz: viriback2misp-0.7/viriback2misp/main.py <==
from .lib.misp import Mispao
from .lib.config import azure_get_secret_value

import os
import configparser
import argparse
from pathlib import Path

KEY_PATH = os.path.join(os.path.expanduser("~"), '.mispao.ini')

def save_data(url:str, key:str="", keyvault_url:str="", secret_name:str="") -> None:
    config = configparser.ConfigParser()
    config['API'] = {'key': key, 'url': url, 'secret_name': secret_name, 'keyvault_url': keyvault_url}
        
    with open(KEY_PATH, 'w') as configfile:
        config.write(configfile)

def main():
    # Start with date arguments
    parser = argparse.ArgumentParser(description='Viriback C2 data to MISP events')

    r_init = True
    if Path(KEY_PATH).exists():
        r_init = False

    parser.add_argument('-i', '--init', action='store_true', dest='init', required=r_init, help="First step. Pass your API key and URL.")
    parser.add_argument('-u', '--update', action='store_true', dest='update', help="Update MISP events.")
    parser.add_argument('-d', '--distribution', choices=[0,1,2,3,4], dest='distribution', default=0, help="""The common distribution levels in MISP are as follows:
        0: Your organization only - Default;
        1: This community only;
        2: Connected communities;
        3: All communities;
        4: Sharing group.""")
    parser.add_argument('-a', '--azure', action='store_true', dest='azure', help="Retrieve misp key directly from Azure key vault.")

    args = parser.parse_args()
    if not args:
        exit()
    else:
        if args.init:
            try:
                keyvault_url = ""
                secret_name = ""
                key = ""
                url = input('Enter your MISP url: ')
                if args.azure:
                    keyvault_url = input('Enter you azure keyvault URL: ')
                    secret_name = input('Enter your secret name: ')
                else:
                    key = input('Enter your key: ')
                save_data(url=url, key=key, keyvault_url=keyvault_url, secret_name=secret_name)
                print(f"[+] Saved config data")
            except Exception as err:
                print(f"[X] Error to save data: {err}")
                exit()
            except KeyboardInterrupt:
                exit()
        elif args.update:
            config = configparser.ConfigParser()
            try:
                config.read(KEY_PATH)

                url = config['API']['url']
                if args.azure:
                    keyvault_url = config['API']['keyvault_url']
                    secret_name = secret_name['API']['secret_name']
                    key = azure_get_secret_value(keyvault_url, secret_name)
                else:
                    key = config['API']['key']

                if not key or not url:
                    print("[X] URL and/or key not found")

                Mispao(url, key, args.distribution)
            except KeyboardInterrupt:
                exit()
            except Exception as err:
                print("[X] Check your config data: {err}")
                exit()

if __name__ == "__main__":
    main()

==> viriback2misp-0.9.tar.gz: viriback2misp-0.9/viriback2misp/main.py <==
from .lib.misp import Mispao
from .lib.config import azure_get_secret_value

import os
import configparser
import argparse
from pathlib import Path

KEY_PATH = os.path.join(os.path.expanduser("~"), '.mispao.ini')

def save_data(url:str, key:str="", keyvault_url:str="", secret_name:str="") -> None:
    config = configparser.ConfigParser()
    config['API'] = {'key': key, 'url': url, 'secret_name': secret_name, 'keyvault_url': keyvault_url}
        
    with open(KEY_PATH, 'w') as configfile:
        config.write(configfile)

def main():
    # Start with date arguments
    parser = argparse.ArgumentParser(description='Viriback C2 data to MISP events')

    r_init = True
    if Path(KEY_PATH).exists():
        r_init = False

    parser.add_argument('-i', '--init', action='store_true', dest='init', required=r_init, help="First step. Pass your API key and URL.")
    parser.add_argument('-u', '--update', action='store_true', dest='update', help="Update MISP events.")
    parser.add_argument('-d', '--distribution', choices=[0,1,2,3,4], dest='distribution', default=0, help="""The common distribution levels in MISP are as follows:
        0: Your organization only - Default;
        1: This community only;
        2: Connected communities;
        3: All communities;
        4: Sharing group.""")
    parser.add_argument('-a', '--azure', action='store_true', dest='azure', help="Retrieve misp key directly from Azure key vault.")

    args = parser.parse_args()
    if not args:
        exit()
    else:
        if args.init:
            try:
                keyvault_url = ""
                secret_name = ""
                key = ""
                url = input('Enter your MISP url: ')
                if args.azure:
                    keyvault_url = input('Enter you azure keyvault URL: ')
                    secret_name = input('Enter your secret name: ')
                else:
                    key = input('Enter your key: ')
                save_data(url=url, key=key, keyvault_url=keyvault_url, secret_name=secret_name)
                print(f"[+] Saved config data")
            except Exception as err:
                print(f"[X] Error to save data: {err}")
                exit()
            except KeyboardInterrupt:
                exit()
        elif args.update:
            config = configparser.ConfigParser()
            try:
                config.read(KEY_PATH)

                url = config['API']['url']
                if args.azure:
                    keyvault_url = config['API']['keyvault_url']
                    secret_name = config['API']['secret_name']
                    key = azure_get_secret_value(keyvault_url, secret_name)
                else:
                    key = config['API']['key']

                if not key or not url:
                    print("[X] URL and/or key not found")

                Mispao(url, key, args.distribution)
            except KeyboardInterrupt:
                exit()
            except Exception as err:
                print(f"[X] Check your config data: {err}")
                exit()

if __name__ == "__main__":
    main()
